==> zio-aws-route53resolver_2.13-5.17.203.2-sources.jar: zio/aws/route53resolver/model/ResolverDNSSECValidationStatus.scala <==
package zio.aws.route53resolver.model
import scala.jdk.CollectionConverters._
sealed trait ResolverDNSSECValidationStatus {
  def unwrap: software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus
}
object ResolverDNSSECValidationStatus {
  def wrap(
      value: software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus
  ): zio.aws.route53resolver.model.ResolverDNSSECValidationStatus =
    value match {
      case software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.UNKNOWN_TO_SDK_VERSION =>
        val r = unknownToSdkVersion
        r
      case software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.ENABLING =>
        val r = ENABLING
        r
      case software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.ENABLED =>
        val r = ENABLED
        r
      case software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.DISABLING =>
        val r = DISABLING
        r
      case software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.DISABLED =>
        val r = DISABLED
        r
    }
  case object unknownToSdkVersion
      extends zio.aws.route53resolver.model.ResolverDNSSECValidationStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object ENABLING
      extends zio.aws.route53resolver.model.ResolverDNSSECValidationStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.ENABLING
  }
  case object ENABLED
      extends zio.aws.route53resolver.model.ResolverDNSSECValidationStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.ENABLED
  }
  case object DISABLING
      extends zio.aws.route53resolver.model.ResolverDNSSECValidationStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.DISABLING
  }
  case object DISABLED
      extends zio.aws.route53resolver.model.ResolverDNSSECValidationStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.DISABLED
  }
}

==> zio-aws-route53resolver_2.13-5.20.22.3-sources.jar: zio/aws/route53resolver/model/ResolverDNSSECValidationStatus.scala <==
package zio.aws.route53resolver.model
import scala.jdk.CollectionConverters._
sealed trait ResolverDNSSECValidationStatus {
  def unwrap: software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus
}
object ResolverDNSSECValidationStatus {
  def wrap(
      value: software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus
  ): zio.aws.route53resolver.model.ResolverDNSSECValidationStatus =
    value match {
      case software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.UNKNOWN_TO_SDK_VERSION =>
        val r = unknownToSdkVersion
        r
      case software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.ENABLING =>
        val r = ENABLING
        r
      case software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.ENABLED =>
        val r = ENABLED
        r
      case software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.DISABLING =>
        val r = DISABLING
        r
      case software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.DISABLED =>
        val r = DISABLED
        r
      case software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.UPDATING_TO_USE_LOCAL_RESOURCE_SETTING =>
        val r = UPDATING_TO_USE_LOCAL_RESOURCE_SETTING
        r
      case software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.USE_LOCAL_RESOURCE_SETTING =>
        val r = USE_LOCAL_RESOURCE_SETTING
        r
    }
  case object unknownToSdkVersion
      extends zio.aws.route53resolver.model.ResolverDNSSECValidationStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object ENABLING
      extends zio.aws.route53resolver.model.ResolverDNSSECValidationStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.ENABLING
  }
  case object ENABLED
      extends zio.aws.route53resolver.model.ResolverDNSSECValidationStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.ENABLED
  }
  case object DISABLING
      extends zio.aws.route53resolver.model.ResolverDNSSECValidationStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.DISABLING
  }
  case object DISABLED
      extends zio.aws.route53resolver.model.ResolverDNSSECValidationStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.DISABLED
  }
  case object UPDATING_TO_USE_LOCAL_RESOURCE_SETTING
      extends zio.aws.route53resolver.model.ResolverDNSSECValidationStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.UPDATING_TO_USE_LOCAL_RESOURCE_SETTING
  }
  case object USE_LOCAL_RESOURCE_SETTING
      extends zio.aws.route53resolver.model.ResolverDNSSECValidationStatus {
    override def unwrap
        : software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus =
      software.amazon.awssdk.services.route53resolver.model.ResolverDNSSECValidationStatus.USE_LOCAL_RESOURCE_SETTING
  }
}
